
# The following code is written in R (www.r-project.org)
# The code can be used to generate the results from the article 
# "Who would pay more for a fragrance-free laundry detergent? How health information affects valuation."


# load packages
# if not already installed on the computer, the following packages
# need to be installed with the command install.packages("packageName")
library(lmtest)
library(sandwich)
library(doBy)
library(survival)

# clear memory (only run if you really want to delet all objects from the workspace)
 rm(list=ls())

# read the data (you need to place them in the working directory. Run getwd() to find out which directory is your working directory)
 data.all<-read.csv("Detergents_data3.csv")

#######################################
# prepare data

   # make some coding unifications
   levels(data.all$KnowDetergentContainsFragrance)
    data.all$KnowDetergentContainsFragrance[data.all$KnowDetergentContainsFragrance=="no"]<-"No"
    data.all$KnowDetergentContainsFragrance[data.all$KnowDetergentContainsFragrance=="NO"]<-"No"
    data.all$KnowDetergentContainsFragrance[data.all$KnowDetergentContainsFragrance=="yes"]<-"Yes"
    data.all$KnowDetergentContainsFragrance[data.all$KnowDetergentContainsFragrance=="YES"]<-"Yes"
    data.all$KnowDetergentContainsFragrance<-factor(data.all$KnowDetergentContainsFragrance, exclude = NULL) 

   levels(data.all$KnowHealthEffectsFragrance)
    data.all$KnowHealthEffectsFragrance[data.all$KnowHealthEffectsFragrance=="yes"]<-"Yes"
    data.all$KnowHealthEffectsFragrance[data.all$KnowHealthEffectsFragrance=="YES"]<-"Yes"
    data.all$KnowHealthEffectsFragrance[data.all$KnowHealthEffectsFragrance=="NO"]<-"No"
    data.all$KnowHealthEffectsFragrance<-factor(data.all$KnowHealthEffectsFragrance, exclude = NULL) 

   levels(data.all$HeardAboutFragranceFreeProduct)
    data.all$HeardAboutFragranceFreeProduct[data.all$HeardAboutFragranceFreeProduct=="yes"]<-"Yes"
    data.all$HeardAboutFragranceFreeProduct[data.all$HeardAboutFragranceFreeProduct=="YES"]<-"Yes"
    data.all$HeardAboutFragranceFreeProduct<-factor(data.all$HeardAboutFragranceFreeProduct, exclude = NULL) 
    

   levels(data.all$AlreadyBoughtFragranceFree)
    data.all$AlreadyBoughtFragranceFree[data.all$AlreadyBoughtFragranceFree==" Never"]<-"Never"
    data.all$AlreadyBoughtFragranceFree<-factor(data.all$AlreadyBoughtFragranceFree, exclude = NULL) 

  
  levels(data.all$Education)  
    data.all$Education[data.all$Education=="Hihg school"]<-"High school"
    data.all$Education<-factor(data.all$Education, exclude = NULL) 

   #re-order levels
  data.all$Education<-factor(data.all$Education, levels= c("less than a high school",
                                    "High school",
                                    "University / College/other degree program",
                                    "Higher than University / College") )

  levels(data.all$CheckIngredientsOfProduct)  
    # relevel
    data.all$CheckIngredientsOfProduct<-factor(data.all$CheckIngredientsOfProduct, levels= c("Never", "Almost never", "Sometimes", "Often", "Always" ) )
  
  levels(data.all$AlreadyBoughtFragranceFree)  
    # relevel
    data.all$AlreadyBoughtFragranceFree<-factor(data.all$AlreadyBoughtFragranceFree, levels= c("Never", "Almost never", "Sometimes", "Often", "Always" ) )

  # some respondents have a WTP for fragrance-free detergents of zero.
  # The WTP after the provision of fragrance health info, is coded as NA
  # Replace the NA by zero
    data.all$WTP_without_afterInfo[data.all$WTP_without_preInfo==0&!is.na(data.all$WTP_without_preInfo)]<-0
    

  # generate some variables
    
    data.all$Diff_WTP_WithoutAfterinfoCurrently<-data.all$WTP_without_afterInfo - data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_WithoutPreinfoCurrently  <-data.all$WTP_without_preInfo   - data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_WithoutAfterinfoWithoutPreinfo  <-data.all$WTP_without_afterInfo   - data.all$WTP_without_preInfo

    data.all$Ecolabel<-"Conventional"
    data.all$Ecolabel[data.all$UsualDetergentBrand=="Bigood"]<-"Eco"
    data.all$Ecolabel[data.all$UsualDetergentBrand=="Denkmit"]<-"Eco"
    data.all$Ecolabel[data.all$UsualDetergentBrand=="Bio Splendid"]<-"Eco"
    data.all$Ecolabel[data.all$UsualDetergentBrand=="Ecover"]<-"Eco"    
    data.all$Ecolabel[data.all$UsualDetergentBrand=="Frosch"]<-"Eco" 

   # generate a variable for those who did not pass the filter question
    data.all$PassFilter<-"Yes"
     data.all$PassFilter[
     data.all$FragranceAllergy=="Yes"|
     data.all$LiveAustria6Months=="NO"|
     data.all$BuyingLiquidDetergent=="NO"|
     data.all$Older18years=="NO"]<-"No"
     table(data.all$PassFilter)
  # no WTP statement
    data.all$NoReplyWTPquestions<-"No"
    data.all$NoReplyWTPquestions[is.na(data.all$WTP_without_preInfo)]<-"Yes"
  # no income info
    levels(data.all$IncomeGroupRespondent)
     data.all$IncomeGroupRespondent.miss<-as.character(data.all$IncomeGroupRespondent)
     data.all$IncomeGroupRespondent.miss[is.na(data.all$IncomeGroupRespondent)]<-"NoReply"
    data.all$IncomeGroupRespondent.miss<-as.factor(data.all$IncomeGroupRespondent.miss)
    levels(data.all$IncomeGroupRespondent.miss) 
    
    
    # Generate the WTP variables with upper and lower bounds and mean
    data.all$WTP_without_preInfo_lower<-data.all$WTP_without_preInfo
    data.all$WTP_without_preInfo_upper<-NA
    data.all$WTP_without_preInfo_upper[data.all$WTP_without_preInfo>=1&!is.na(data.all$WTP_without_preInfo)]<-data.all$WTP_without_preInfo[data.all$WTP_without_preInfo>=1&!is.na(data.all$WTP_without_preInfo)]+.5
    data.all$WTP_without_preInfo_upper[data.all$WTP_without_preInfo==0&!is.na(data.all$WTP_without_preInfo)]<-0
    data.all$WTP_without_preInfo_mean <-(data.all$WTP_without_preInfo_upper+data.all$WTP_without_preInfo_lower)/ 2
    data.all$Diff_WTP_without_preInfo_lower_current<-data.all$WTP_without_preInfo_lower-data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_without_preInfo_upper_current<-data.all$WTP_without_preInfo_upper-data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_without_preInfo_mean_current <-data.all$WTP_without_preInfo_mean -data.all$UsualDetergentBrandEuro
    
        
    data.all$WTP_without_afterInfo_lower<-data.all$WTP_without_afterInfo
    data.all$WTP_without_afterInfo_upper<-NA
    data.all$WTP_without_afterInfo_upper[data.all$WTP_without_afterInfo>=1&!is.na(data.all$WTP_without_afterInfo)]<-data.all$WTP_without_afterInfo[data.all$WTP_without_afterInfo>=1&!is.na(data.all$WTP_without_afterInfo)]+.5
    data.all$WTP_without_afterInfo_upper[data.all$WTP_without_afterInfo==0&!is.na(data.all$WTP_without_afterInfo)]<-0
    data.all$WTP_without_afterInfo_mean <-(data.all$WTP_without_afterInfo_upper+data.all$WTP_without_afterInfo_lower)/ 2
    data.all$Diff_WTP_without_afterInfo_lower_current<-data.all$WTP_without_afterInfo_lower-data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_without_afterInfo_upper_current<-data.all$WTP_without_afterInfo_upper-data.all$UsualDetergentBrandEuro
    data.all$Diff_WTP_without_afterInfo_mean_current <-data.all$WTP_without_afterInfo_mean -data.all$UsualDetergentBrandEuro
    
     data.all$Diff_WTP_without_afterInfo_upper_preInfo_lower<-data.all$WTP_without_afterInfo_upper-data.all$WTP_without_preInfo_lower # highest possible difference
     data.all$Diff_WTP_without_afterInfo_lower_preInfo_upper<-data.all$WTP_without_afterInfo_lower-data.all$WTP_without_preInfo_upper # lowest possible difference
     data.all$Diff_WTP_without_afterInfo_mean_preInfo_mean  <-data.all$WTP_without_afterInfo_mean -data.all$WTP_without_preInfo_mean
     
    
    
    
    
##########
# drop those observations that do not pass the filter question or don't give a WTP reply

  ddata<-data.all[data.all$NoReplyWTPquestions=="No"&data.all$PassFilter=="Yes",]   
  ddata$KnowHealthEffectsFragrance<-factor(ddata$KnowHealthEffectsFragrance, exclude = NULL)    
  ddata$KnowDetergentContainsFragrance<-factor(ddata$KnowDetergentContainsFragrance , exclude = NULL)    
  ddata$HeardAboutFragranceFreeProduct<-factor(ddata$HeardAboutFragranceFreeProduct , exclude = NULL)    
  ddata$CheckIngredientsOfProduct<-factor(ddata$CheckIngredientsOfProduct , exclude = NULL)    
  ddata$AlreadyBoughtFragranceFree<-factor(ddata$AlreadyBoughtFragranceFree , exclude = NULL)    
    
 
    

#######
#Descriptive statistiscs

  # respondents' characteristics 
    sum.Gender                <- with(ddata, table(Gender)/sum(table(Gender)) )    
    sum.AgeGroup              <- with(ddata, table(AgeGroup)/sum(table(AgeGroup)) ) 
    sum.Education             <- with(ddata, table(Education)/sum(table(Education)) ) 
    sum.HouseholdSize         <- with(ddata, table(HouseholdSize)/sum(table(HouseholdSize)) )          
    sum.IncomeGroupRespondent <- with(ddata, table(IncomeGroupRespondent.miss)/sum(table(IncomeGroupRespondent.miss)) )    

 table.HHcharactaristics<- rbind(
   c(names(sum.Gender),  NA, NA, NA      ),
   c(      sum.Gender,   NA, NA, NA      ),
   c(names(sum.AgeGroup),NA              ),
   c(      sum.AgeGroup, NA              ), 
   c(names(sum.Education),NA             ),
   c(      sum.Education, NA             ), 
   c(names(sum.HouseholdSize)            ),
   c(      sum.HouseholdSize             ), 
   c(names(sum.IncomeGroupRespondent)),
   c(      sum.IncomeGroupRespondent ) 
   )  
    rownames(table.HHcharactaristics)<-c("Gender", "", "Age Group", "", "Education", "", "Household size", "", "Income Respondent", "")
    colnames(table.HHcharactaristics)<-rep("",times= ncol(table.HHcharactaristics))

    
  # Respondents knowldege and attitudes
   sum.KnowDetergentContainsFragrance<-with(ddata, table(KnowDetergentContainsFragrance) /sum(table(KnowDetergentContainsFragrance))) 
   sum.KnowHealthEffectsFragrance    <-with(ddata, table(KnowHealthEffectsFragrance)     /sum(table(KnowHealthEffectsFragrance))  ) 
   sum.HeardAboutFragranceFreeProduct<-with(ddata, table(HeardAboutFragranceFreeProduct) /sum(table(HeardAboutFragranceFreeProduct))) 
   sum.CheckIngredientsOfProduct     <-with(ddata, table(CheckIngredientsOfProduct)      /sum(table(CheckIngredientsOfProduct))   ) 
   sum.AlreadyBoughtFragranceFree    <-with(ddata, table(AlreadyBoughtFragranceFree)     /sum(table(AlreadyBoughtFragranceFree))  ) 

 table.KnowledgeAttitudes<- rbind(
   c(names(sum.KnowDetergentContainsFragrance),  NA, NA, NA     ),
   c(      sum.KnowDetergentContainsFragrance ,  NA, NA, NA     ),
   c(names(sum.KnowHealthEffectsFragrance)    ,  NA, NA, NA     ),
   c(      sum.KnowHealthEffectsFragrance     ,  NA, NA, NA     ), 
   c(names(sum.HeardAboutFragranceFreeProduct),  NA, NA, NA     ),
   c(      sum.HeardAboutFragranceFreeProduct,   NA, NA, NA     ), 
   c(names(sum.CheckIngredientsOfProduct)                       ),
   c(      sum.CheckIngredientsOfProduct                        ), 
   c(names(sum.AlreadyBoughtFragranceFree)                      ),
   c(      sum.AlreadyBoughtFragranceFree                       ) 
   )  
    rownames(table.KnowledgeAttitudes)<-c("Know detergent contains fragrance", "", "Know health effects of fragrance", "", "Know about fragrance free products", "", "Check ingredients of products", "", "Already bought fragrance free products", "")
    colnames(table.KnowledgeAttitudes)<-rep("",times= ncol(table.KnowledgeAttitudes))


  #### summary statistic WTP
    
    # share of those with negative WTP
     table(ddata$Diff_WTP_WithoutPreinfoCurrently>=0)/sum(table(ddata$Diff_WTP_WithoutPreinfoCurrently>=0))

    sum.WTP<-matrix(
            summaryBy(UsualDetergentBrandEuro+WTP_without_preInfo+WTP_without_afterInfo+
                        Diff_WTP_WithoutPreinfoCurrently+Diff_WTP_WithoutAfterinfoCurrently+Diff_WTP_WithoutAfterinfoWithoutPreinfo~1, 
              data=ddata, FUN=c(mean,median, sd, min, max), na.rm=TRUE), 
            byrow = FALSE,
            ncol=5
                 )
    
     colnames(sum.WTP)<-c("Mean","Median", "St. Dev.", "Min", "Max")
     rownames(sum.WTP)<-c("Current expenditure (a)", "WTP for fragrance-free before info (b)", "WTP for fragrance-free after info (c)",
                          "(b)-(a)", "(c)-(a)", "(c)-(b)")
       

  # Current detergent choice 
   sum.UsualDetergentBrandEuro <-with(ddata,      table(UsualDetergentBrandEuro)/sum(table(UsualDetergentBrandEuro))  )     
   sum.UsualDetergentBrand     <-with(ddata, sort(table(UsualDetergentBrand    )/sum(table(UsualDetergentBrand    ))) ) 
   
   DetergentBrand.prices<-with(ddata, tapply(X=UsualDetergentBrandEuro, INDEX=UsualDetergentBrand, mean))
       DetergentBrand.prices[names(sum.UsualDetergentBrand)]

  
 names(sum.UsualDetergentBrand)%in%unique(ddata$UsualDetergentBrand[ddata$Ecolabel=="Eco"])

 
 # plot currently bought detergents (not shown in the article) 
  lables.barplotUsualdetergent<- paste(
    names(sum.UsualDetergentBrand), 
    ifelse(names(sum.UsualDetergentBrand)%in%unique(ddata$UsualDetergentBrand[ddata$Ecolabel=="Eco"]), "*",""), 
    ", ", 
    round(DetergentBrand.prices[names(sum.UsualDetergentBrand)],1), 
    "€/L", sep=""
      ) 
 
 paste("detergent", ifelse(ddata$Ecolabel=="Eco", "*","") , sep="")
 

  with(ddata, barplot( sum.UsualDetergentBrand,
                       names.arg=lables.barplotUsualdetergent, 
                       las=2, 
                       main="Brands usually bought by respondents", 
                       #xlab="Brand name and average price",
                       ylab="% of respondents"
                       )) 


   # plot consumer types(not shown in the paper)

  # after info
   plot(jitter(ddata$UsualDetergentBrandEuro, factor=4)~jitter(ddata$Diff_WTP_without_preInfo_lower_current, factor=4),#data=ddata, 
        xlab= "WTP for change to fragrance-free detergent (€/Ltr)", ylab= "Price of current detergent (€/Ltr)",
          lwd=2,
      # main="After information", 
      col= ddata$IncomeGroupRespondent.miss,
      pch=8)
   abline(v=0);abline(h= mean(ddata$UsualDetergentBrandEuro) )
  legend("bottomleft", legend = c("0- 1500", "1501-3000", "3001-4500", "Over 4501", "No Reply"),  col = 1:5, 
        bty = "n", title="Income €/month:",pch=8)
  
  text("Type 1", x= 1 ,y=4.3, lwd=3)
  text("Type 2", x=-2 ,y=2.4, lwd=3)
  text("Type 3", x=-2 ,y=4.3, lwd=3)
  text("Type 4", x= 1 ,y=2.4, lwd=3)
  
 
#####################################
# regression analysis

#### Simple linear regression)
  
  # dependent variable: current price 
  equ.lm.CurrentPriceUnconditional<- UsualDetergentBrandEuro~ IncomeGroupRespondent.miss
   res.lm.CurrentPriceUnconditional  <-lm(equ.lm.CurrentPriceUnconditional, data=ddata)
    summary(res.lm.CurrentPriceUnconditional)  
   coeftest(res.lm.CurrentPriceUnconditional, vcov=vcovHC)

  # dependent variable: WTP for fragrance-free detergent before information
  equ.lm.DiffPreInfoUnconditional<-Diff_WTP_WithoutPreinfoCurrently~  IncomeGroupRespondent.miss
#     KnowHealthEffectsFragrance
   res.lm.DiffPreInfoUnconditional  <-lm(equ.lm.DiffPreInfoUnconditional, data=ddata)
    summary(res.lm.DiffPreInfoUnconditional)  
   coeftest(res.lm.DiffPreInfoUnconditional, vcov=vcovHC)

  # dependent variable: WTP for fragrance-free detergent after information
   equ.lm.DiffAfterInfoUnconditional<-Diff_WTP_WithoutAfterinfoCurrently~ IncomeGroupRespondent.miss
   res.lm.DiffAfterInfoUnconditional  <-lm(equ.lm.DiffAfterInfoUnconditional, data=ddata)
    summary(res.lm.DiffAfterInfoUnconditional)  
   coeftest(res.lm.DiffAfterInfoUnconditional, vcov=vcovHC)
   

  # dependent variable: difference after information with before information
   equ.lm.DiffAfterinfoBeforeinfoUnconditional<-Diff_WTP_WithoutAfterinfoWithoutPreinfo~IncomeGroupRespondent.miss
   res.lm.DiffAfterinfoBeforeinfoUnconditional  <-lm(equ.lm.DiffAfterinfoBeforeinfoUnconditional, data=ddata)
    summary(res.lm.DiffAfterinfoBeforeinfoUnconditional)  
   coeftest(res.lm.DiffAfterinfoBeforeinfoUnconditional, vcov=vcovHC)

   
     # summarize results in a table
     reg.resultsUnconditional<-data.frame(
      coeftest(res.lm.CurrentPriceUnconditional, vcov=vcovHC)[,c(1,2,4)], 
     "star1"=NA, 
      coeftest(res.lm.DiffPreInfoUnconditional, vcov=vcovHC)[,c(1,2,4)], 
     "star2"=NA,
      coeftest(res.lm.DiffAfterInfoUnconditional, vcov=vcovHC)[,c(1,2,4)],
     "star3"=NA,
      coeftest(res.lm.DiffAfterinfoBeforeinfoUnconditional, vcov=vcovHC)[,c(1,2,4)],
     "star4"=NA)
     # add stars
      reg.resultsUnconditional$star1[reg.resultsUnconditional[, 3]<=0.10]<-"*"
      reg.resultsUnconditional$star1[reg.resultsUnconditional[, 3]<=0.05]<-"**"
      reg.resultsUnconditional$star2[reg.resultsUnconditional[, 7]<=0.10]<-"*"
      reg.resultsUnconditional$star2[reg.resultsUnconditional[, 7]<=0.05]<-"**"
      reg.resultsUnconditional$star3[reg.resultsUnconditional[,11]<=0.10]<-"*"
      reg.resultsUnconditional$star3[reg.resultsUnconditional[,11]<=0.05]<-"**"
      reg.resultsUnconditional$star4[reg.resultsUnconditional[,15]<=0.10]<-"*"
      reg.resultsUnconditional$star4[reg.resultsUnconditional[,15]<=0.05]<-"**"
     # replace NA with ""
      reg.resultsUnconditional$star1[is.na(reg.resultsUnconditional$star1)]<-""
      reg.resultsUnconditional$star2[is.na(reg.resultsUnconditional$star2)]<-""
      reg.resultsUnconditional$star3[is.na(reg.resultsUnconditional$star3)]<-""
      reg.resultsUnconditional$star4[is.na(reg.resultsUnconditional$star4)]<-""
     # drop p-values
      reg.resultsUnconditional<-reg.resultsUnconditional[,-c(3,7,11,15)]
     # add R^2
     reg.resultsUnconditional<-rbind(reg.resultsUnconditional, "R^2"=c(
                          summary(res.lm.CurrentPriceUnconditional)$r.squared, NA,NA,
                          summary(res.lm.DiffPreInfoUnconditional)$r.squared, NA,NA,
                          summary(res.lm.DiffAfterInfoUnconditional)$r.squared, NA,NA,
                          summary(res.lm.DiffAfterinfoBeforeinfoUnconditional)$r.squared, NA, NA))
     
     reg.resultsUnconditional<-rbind(reg.resultsUnconditional, "Note:"=c("*=10%,**=5%", NA, NA, NA,NA,NA,NA,NA,NA, NA,NA,NA ))
   
     colnames(reg.resultsUnconditional)<-c("Currently","","" , "Diff Beforeinfo-currently", "","", "Diff Afterinfo-currently", "", "","Diff Afterinfo-Beforeinfo", "","")
    



 ### Multiple Regression 
  # dependent variable: current price 
  equ.lm.CurrentPrice<- UsualDetergentBrandEuro~
      Ecolabel+ 
      Gender+
      AgeGroup+
      Education+
      HouseholdSize+
     IncomeGroupRespondent.miss+
     KnowHealthEffectsFragrance
   res.lm.CurrentPrice  <-lm(equ.lm.CurrentPrice, data=ddata)
    summary(res.lm.CurrentPrice)  
   coeftest(res.lm.CurrentPrice, vcov=vcovHC)

 
  # dependent variable: WTP for fragrance-free detergent before information
  equ.lm.DiffPreInfo<-Diff_WTP_WithoutPreinfoCurrently~UsualDetergentBrandEuro+
      Ecolabel+
      Gender+
      AgeGroup+
      Education+
      HouseholdSize+
     IncomeGroupRespondent.miss+
     KnowHealthEffectsFragrance
   res.lm.DiffPreInfo  <-lm(equ.lm.DiffPreInfo, data=ddata)
    summary(res.lm.DiffPreInfo)  
   coeftest(res.lm.DiffPreInfo, vcov=vcovHC)

  # dependent variable: WTP for fragrance-free detergent after information
  equ.lm.DiffAfterInfo<-Diff_WTP_WithoutAfterinfoCurrently~UsualDetergentBrandEuro+
      Ecolabel+
      Gender+
      AgeGroup+
      Education+
      HouseholdSize+
     IncomeGroupRespondent.miss+
     KnowHealthEffectsFragrance
   res.lm.DiffAfterInfo  <-lm(equ.lm.DiffAfterInfo, data=ddata)
    summary(res.lm.DiffAfterInfo)  
   coeftest(res.lm.DiffAfterInfo, vcov=vcovHC)
   
  # dependent variable: difference after information with before information
  equ.lm.DiffAfterinfoBeforeinfo<-Diff_WTP_WithoutAfterinfoWithoutPreinfo~UsualDetergentBrandEuro+
     Ecolabel+
     Gender+
     AgeGroup+
     Education+
     HouseholdSize+
     IncomeGroupRespondent.miss+
     KnowHealthEffectsFragrance
   res.lm.DiffAfterinfoBeforeinfo  <-lm(equ.lm.DiffAfterinfoBeforeinfo, data=ddata)
    summary(res.lm.DiffAfterinfoBeforeinfo)  
   coeftest(res.lm.DiffAfterinfoBeforeinfo, vcov=vcovHC)

     # summarize regression  results in a table
      
      temp<-coeftest(res.lm.CurrentPrice, vcov=vcovHC)[,c(1,2,4)]
      temp<-rbind("(Intercept)"=temp["(Intercept)",],"UsualDetergentBrandEuro"=NA, temp[(rownames(temp)[-1]),])
     reg.results<-data.frame(
      temp,
     "star1"=NA,
       coeftest(res.lm.DiffPreInfo, vcov=vcovHC)[,c(1,2,4)], 
     "star2"=NA,
      coeftest(res.lm.DiffAfterInfo, vcov=vcovHC)[,c(1,2,4)],
     "star3"=NA,
      coeftest(res.lm.DiffAfterinfoBeforeinfo, vcov=vcovHC)[,c(1,2,4)],
     "star4"=NA)
     # add stars
      reg.results$star1[reg.results[, 3]<=0.10]<-"*"
      reg.results$star1[reg.results[, 3]<=0.05]<-"**"
      reg.results$star2[reg.results[, 7]<=0.10]<-"*"
      reg.results$star2[reg.results[, 7]<=0.05]<-"**"
      reg.results$star3[reg.results[,11]<=0.10]<-"*"
      reg.results$star3[reg.results[,11]<=0.05]<-"**"
      reg.results$star4[reg.results[,15]<=0.10]<-"*"
      reg.results$star4[reg.results[,15]<=0.05]<-"**"
     # replace NA with ""
      reg.results$star1[is.na(reg.results$star1)]<-""
      reg.results$star2[is.na(reg.results$star2)]<-""
      reg.results$star3[is.na(reg.results$star3)]<-""
      reg.results$star4[is.na(reg.results$star4)]<-""
      
     # drop p-values
      reg.results<-reg.results[,-c(3,7,11, 15)]
     # add R^2
     reg.results<-rbind(reg.results, "R^2"=c(
                          summary(res.lm.CurrentPrice)$r.squared, NA,NA,
                          summary(res.lm.DiffPreInfo)$r.squared, NA,NA,
                          summary(res.lm.DiffAfterInfo)$r.squared, NA,NA,
                          summary(res.lm.DiffAfterinfoBeforeinfo)$r.squared, NA, NA))
     
     reg.results<-rbind(reg.results, "Note:"=c("*=10%,**=5%", NA, NA, NA,NA,NA,NA,NA,NA, NA, NA, NA))
   
     colnames(reg.results)<-c("Current", "", "" , "Diff Beforeinfo-currently", "","", "Diff Afterinfo-currently", "", "","Diff Afterinfo-Beforeinfo", "","")
    
     

  ### interval regression
     
   #    a left censored observation where time of event < t: represented as (NA, t)
   #    a right censored observation where time of event >t: represented as (t, NA)
   #    an interval censored observations t1<=time <= t2   : represented as (t1,t2)

   eventD <- rep(3, nrow(ddata) )
   eventD[ddata$WTP_without_preInfo == 0]<-2
   ddata$eventD<-eventD
   
    
        (Diff_WTP_preInfo_current_interval <- with(ddata, 
                           Surv(Diff_WTP_without_preInfo_lower_current, 
                                Diff_WTP_without_preInfo_upper_current, 
                                event = eventD, 
                                type = "interval")))
        (Diff_WTP_afterInfo_current_interval <- with(ddata, 
                           Surv(Diff_WTP_without_afterInfo_lower_current, 
                                Diff_WTP_without_afterInfo_upper_current, 
                                event = eventD, 
                                type = "interval")))
   
        (Diff_WTP_afterInfo_preInfo_interval <- with(ddata, 
                           Surv(Diff_WTP_without_afterInfo_lower_preInfo_upper,
                                Diff_WTP_without_afterInfo_upper_preInfo_lower, 
                                event = eventD, 
                                type = "interval")))
   
   
     equ_Diff_WTP_without_preInfo_lower_current <-as.formula(
                        Diff_WTP_preInfo_current_interval~
                       UsualDetergentBrandEuro+
                       Ecolabel+
                       Gender+
                       AgeGroup+
                       Education+
                       HouseholdSize+
                       IncomeGroupRespondent.miss+
                       KnowHealthEffectsFragrance)

       
     equ_Diff_WTP_without_afterInfo_lower_current <-as.formula(
                        Diff_WTP_afterInfo_current_interval~
                       UsualDetergentBrandEuro+
                       Ecolabel+
                       Gender+
                       AgeGroup+
                       Education+
                       HouseholdSize+
                       IncomeGroupRespondent.miss+
                       KnowHealthEffectsFragrance)
 
     equ_Diff_WTP_afterInfo_preInfo_interval <-as.formula(
                        Diff_WTP_afterInfo_preInfo_interval~
                       UsualDetergentBrandEuro+
                       Ecolabel+
                       Gender+
                       AgeGroup+
                       Education+
                       HouseholdSize+
                       IncomeGroupRespondent.miss+
                       KnowHealthEffectsFragrance)
                           
   intervalEst_eDiff_WTP_without_preInfo_lower_current <- survreg(equ_Diff_WTP_without_preInfo_lower_current,                            
                           data = ddata,
                           dist = "gaussian", 
                           robust= TRUE, 
                           model=TRUE   )
   
   intervalEst_Diff_WTP_without_afterInfo_lower_current <- survreg(equ_Diff_WTP_without_afterInfo_lower_current,                            
                           data = ddata,
                           dist = "gaussian", 
                           robust= TRUE, 
                           model=TRUE   )

   intervalEst_Diff_WTP_afterInfo_preInfo_interval <- survreg(equ_Diff_WTP_afterInfo_preInfo_interval,                            
                           data = ddata,
                           dist = "gaussian", 
                           robust= TRUE, 
                          model=TRUE   )
      
     
     sum.1<-summary(intervalEst_eDiff_WTP_without_preInfo_lower_current)
     sum.2<-summary(intervalEst_Diff_WTP_without_afterInfo_lower_current)
     sum.3<-summary(intervalEst_Diff_WTP_afterInfo_preInfo_interval)
     
     
       # summarize results in a table
     reg.results.interval<-data.frame(
       sum.1$table[,c(1,2,5)], 
     "star1"=NA,
       sum.2$table[,c(1,2,5)],
     "star2"=NA,
      sum.3$table[,c(1,2,5)],
     "star3"=NA)
     # add stars
      reg.results.interval$star1[reg.results.interval[, 3]<=0.10]<-"*"
      reg.results.interval$star1[reg.results.interval[, 3]<=0.05]<-"**"
      reg.results.interval$star2[reg.results.interval[, 7]<=0.10]<-"*"
      reg.results.interval$star2[reg.results.interval[, 7]<=0.05]<-"**"
      reg.results.interval$star3[reg.results.interval[,11]<=0.10]<-"*"
      reg.results.interval$star3[reg.results.interval[,11]<=0.05]<-"**"
     # replace NA with ""
      reg.results.interval$star1[is.na(reg.results.interval$star1)]<-""
      reg.results.interval$star2[is.na(reg.results.interval$star2)]<-""
      reg.results.interval$star3[is.na(reg.results.interval$star3)]<-""
     # drop p-values
      reg.results.interval<-reg.results.interval[,-c(3,7,11)]
     # add R^2
     reg.results.interval<-rbind(reg.results.interval, "Note:"=c("*=10%,**=5%", NA, NA, NA,NA,NA,NA,NA,NA ))
   
     colnames(reg.results.interval)<-c("Diff Beforeinfo-currently", "","", "Diff Afterinfo-currently", "", "","Diff Afterinfo-Beforeinfo", "","")
    

     
################################
# Numerical illustration
 #Welfare effects of consumers of two scenarios (with and without information)
   
  pricesFFvaraint<-matrix(seq(from=0,to=6,by=.1),ncol=1)
   
   ConsWelfareSim<-matrix(0, nrow = nrow(ddata), ncol=length(pricesFFvaraint)*2)
   rownames(ConsWelfareSim) <- ddata$id
   colnames(ConsWelfareSim) <- c( paste("Sc1.pFF",as.character(pricesFFvaraint), sep=""), paste("Sc2.pFF",as.character(pricesFFvaraint), sep="") )
     
   columnNo<-0
   for(pFF in pricesFFvaraint){
     columnNo<-columnNo+1
    # Scenario 1 (no information):
     #buyerPreInfo<-with(ddata,UsualDetergentBrandEuro<WTP_without_preInfo )
     buyerPreInfo<-with(ddata,  pFF>=UsualDetergentBrandEuro & pFF <= WTP_without_preInfo )
     #ConsWelfareSim[columnNo]<-0
     if( table(buyerPreInfo)["FALSE"]!=nrow(ConsWelfareSim) ){
     ConsWelfareSim[buyerPreInfo,columnNo]<-with(ddata, WTP_without_preInfo[buyerPreInfo]-UsualDetergentBrandEuro[buyerPreInfo])
     }
     
     
    # Scenario 2 (after Information):
     #buyerAfterInfo<-with(ddata,UsualDetergentBrandEuro<WTP_without_afterInfo )
     buyerAfterInfo<-with(ddata,pFF>=UsualDetergentBrandEuro & pFF <= WTP_without_afterInfo )
     #ConsWelfareSim[columnNo+length(pricesFFvaraint)]<-0
     if( table(buyerAfterInfo)["FALSE"]!=nrow(ConsWelfareSim) ){
     ConsWelfareSim[buyerAfterInfo, (columnNo+length(pricesFFvaraint))]<-with(ddata, WTP_without_afterInfo[buyerAfterInfo]-UsualDetergentBrandEuro[buyerAfterInfo])
     }
     
   }
   

     welfareByPriceFF.beforeInfo.IncomeAll  <- colMeans(ConsWelfareSim[,1:length(pricesFFvaraint)])
     welfareByPriceFF.afterInfo.IncomeAll   <- colMeans(ConsWelfareSim[,(length(pricesFFvaraint)+1):(length(pricesFFvaraint)*2)])
 
    

   
     temp<-as.data.frame(ConsWelfareSim)
     temp$IncomeGroupRespondent.miss <- ddata$IncomeGroupRespondent.miss
     
           with(ddata[ddata$IncomeGroupRespondent.miss=="NoReply",], WTP_without_afterInfo-UsualDetergentBrandEuro)
             temp[temp$IncomeGroupRespondent.miss=="NoReply",]
             priceTemp<-4.5
              with(ddata[ddata$IncomeGroupRespondent.miss=="NoReply",],  priceTemp>=UsualDetergentBrandEuro & priceTemp <= WTP_without_afterInfo )
             
             
     welfareByPriceFF.beforeInfo.IncomeDisagg <- summaryBy(list( names(temp[,1:length(pricesFFvaraint)]),                               "IncomeGroupRespondent.miss"), FUN=mean,  data=temp)
     welfareByPriceFF.afterInfo.IncomeDisagg  <- summaryBy(list( names(temp[,(length(pricesFFvaraint)+1):(length(pricesFFvaraint)*2)]), "IncomeGroupRespondent.miss"), FUN=mean,  data=temp)
                                     
     rownames(welfareByPriceFF.beforeInfo.IncomeDisagg)<- welfareByPriceFF.beforeInfo.IncomeDisagg$IncomeGroupRespondent.miss
     rownames(welfareByPriceFF.afterInfo.IncomeDisagg) <- welfareByPriceFF.afterInfo.IncomeDisagg$IncomeGroupRespondent.miss
     # drop the first column because it includes info on the income category
     welfareByPriceFF.beforeInfo.IncomeDisagg <- welfareByPriceFF.beforeInfo.IncomeDisagg[,-1]
     welfareByPriceFF.afterInfo.IncomeDisagg  <- welfareByPriceFF.afterInfo.IncomeDisagg[,-1]

  # calculate moving average
    widthMA<-5
    # before Info
    welfareByPriceFF.beforeInfo.IncomeAllMA      <-rollapply(welfareByPriceFF.beforeInfo.IncomeAll,        widthMA, mean, partial=TRUE)
    welfareByPriceFF.beforeInfo.IncomeDisagg.1MA <-rollapply(t(welfareByPriceFF.beforeInfo.IncomeDisagg)[,1], widthMA, mean, partial=TRUE)
    welfareByPriceFF.beforeInfo.IncomeDisagg.2MA <-rollapply(t(welfareByPriceFF.beforeInfo.IncomeDisagg)[,2], widthMA, mean, partial=TRUE)
    welfareByPriceFF.beforeInfo.IncomeDisagg.3MA <-rollapply(t(welfareByPriceFF.beforeInfo.IncomeDisagg)[,3], widthMA, mean, partial=TRUE)
    welfareByPriceFF.beforeInfo.IncomeDisagg.4MA <-rollapply(t(welfareByPriceFF.beforeInfo.IncomeDisagg)[,4], widthMA, mean, partial=TRUE)
    welfareByPriceFF.beforeInfo.IncomeDisagg.5MA <-rollapply(t(welfareByPriceFF.beforeInfo.IncomeDisagg)[,5], widthMA, mean, partial=TRUE)

    # after Info
    welfareByPriceFF.afterInfo.IncomeAllMA      <-rollapply(welfareByPriceFF.afterInfo.IncomeAll,        widthMA, mean, partial=TRUE)
    welfareByPriceFF.afterInfo.IncomeDisagg.1MA <-rollapply(t(welfareByPriceFF.afterInfo.IncomeDisagg)[,1], widthMA, mean, partial=TRUE)
    welfareByPriceFF.afterInfo.IncomeDisagg.2MA <-rollapply(t(welfareByPriceFF.afterInfo.IncomeDisagg)[,2], widthMA, mean, partial=TRUE)
    welfareByPriceFF.afterInfo.IncomeDisagg.3MA <-rollapply(t(welfareByPriceFF.afterInfo.IncomeDisagg)[,3], widthMA, mean, partial=TRUE)
    welfareByPriceFF.afterInfo.IncomeDisagg.4MA <-rollapply(t(welfareByPriceFF.afterInfo.IncomeDisagg)[,4], widthMA, mean, partial=TRUE)
    welfareByPriceFF.afterInfo.IncomeDisagg.5MA <-rollapply(t(welfareByPriceFF.afterInfo.IncomeDisagg)[,5], widthMA, mean, partial=TRUE)
        
  

  plot(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeAll,   type="l", 
       main = "Before health information", ylab="Mean welfare change per person in € \n when buying 1 Ltr detergent \n given 1 fragrance-free detergent is on the market", 
       ylim = c(-0.1,0.5),
       xlab = "Price of the 1 fragrance-free detergent on the market in €/Ltr",                                 lty=3, lwd=2)
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg[1,], col="blue",       lty=3, lwd=2)
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg[2,], col="violet",   lty=3, lwd=2)   
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg[3,], col="darkgreen",  lty=3, lwd=2)   
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg[4,], col="red",        lty=3, lwd=2)   
   #lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg[5,], col="gray",      lty=3, lwd=1)   
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeAllMA, col="black",            lty=1, lwd=5)
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg.1MA, col="blue",        lty=1, lwd=5)
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg.2MA, col="violet",    lty=1, lwd=5)   
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg.3MA, col="darkgreen",   lty=1, lwd=5)   
   lines(pricesFFvaraint, welfareByPriceFF.beforeInfo.IncomeDisagg.4MA, col="red",         lty=1, lwd=5)   
   #lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.5MA, col="gray",       lty=1, lwd=2)   
 
   legend("topleft", legend = c("All income groups", "income <1500 €/month",  "income 1501-3000 €/month", 
                                 "income 3001-4500 €/month", "income >4501 €/month"),
          col = c("black","blue", "violet", "darkgreen", "red"), 
        bty = "n", lwd=c(5,5,5,5,5), lty=c(1,1,1,1,1) )
  text ( 0,-0.05, pos=4, "Fat lines are moving average values of five dotted line values calculated at 0.1€ price steps")
   
   abline(h=0)



  plot(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeAll,   type="l", 
       main = "After health information", ylab="Mean welfare change per person in € \n when buying 1 Ltr detergent \n given 1 fragrance-free detergent is on the market", 
       ylim = c(-0.1,0.5),
       xlab = "Price of the 1 fragrance-free detergent on the market in €/Ltr",                                 lty=3, lwd=2)
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg[1,], col="blue",       lty=3, lwd=2)
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg[2,], col="violet",   lty=3, lwd=2)   
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg[3,], col="darkgreen",  lty=3, lwd=2)   
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg[4,], col="red",        lty=3, lwd=2)   
   #lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg[5,], col="gray",      lty=3, lwd=1)   
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeAllMA, col="black",            lty=1, lwd=5)
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.1MA, col="blue",        lty=1, lwd=5)
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.2MA, col="violet",    lty=1, lwd=5)   
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.3MA, col="darkgreen",   lty=1, lwd=5)   
   lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.4MA, col="red",         lty=1, lwd=5)   
   #lines(pricesFFvaraint, welfareByPriceFF.afterInfo.IncomeDisagg.5MA, col="gray",       lty=1, lwd=2)   
 
   legend("topleft", legend = c("All income groups", "income <1500 €/month",  "income 1501-3000 €/month", 
                                 "income 3001-4500 €/month", "income >4501 €/month"),
          col = c("black","blue", "violet", "darkgreen", "red"), 
        bty = "n", lwd=c(5,5,5,5,5), lty=c(1,1,1,1,1) )
  text ( 0,-0.05, pos=4, "Fat lines are moving average values of five dotted line values calculated at 0.1€ price steps")
   
   abline(h=0)

   
   
   table.Welfare    <- 
              cbind( 
              rbind(
              welfareByPriceFF.beforeInfo.IncomeAll[c("Sc1.pFF2", "Sc1.pFF3","Sc1.pFF4","Sc1.pFF5","Sc1.pFF6")], 
              welfareByPriceFF.beforeInfo.IncomeDisagg[1,c("Sc1.pFF2.mean","Sc1.pFF3.mean","Sc1.pFF4.mean","Sc1.pFF5.mean","Sc1.pFF6.mean")],
              welfareByPriceFF.beforeInfo.IncomeDisagg[2,c("Sc1.pFF2.mean","Sc1.pFF3.mean","Sc1.pFF4.mean","Sc1.pFF5.mean","Sc1.pFF6.mean")],
              welfareByPriceFF.beforeInfo.IncomeDisagg[3,c("Sc1.pFF2.mean","Sc1.pFF3.mean","Sc1.pFF4.mean","Sc1.pFF5.mean","Sc1.pFF6.mean")],
              welfareByPriceFF.beforeInfo.IncomeDisagg[4,c("Sc1.pFF2.mean","Sc1.pFF3.mean","Sc1.pFF4.mean","Sc1.pFF5.mean","Sc1.pFF6.mean")],
              welfareByPriceFF.beforeInfo.IncomeDisagg[5,c("Sc1.pFF2.mean","Sc1.pFF3.mean","Sc1.pFF4.mean","Sc1.pFF5.mean","Sc1.pFF6.mean")]
              ),
              rbind(
              welfareByPriceFF.afterInfo.IncomeAll[c("Sc2.pFF2", "Sc2.pFF3","Sc2.pFF4","Sc2.pFF5","Sc2.pFF6")], 
              welfareByPriceFF.afterInfo.IncomeDisagg[1,c("Sc2.pFF2.mean","Sc2.pFF3.mean","Sc2.pFF4.mean","Sc2.pFF5.mean","Sc2.pFF6.mean")],
              welfareByPriceFF.afterInfo.IncomeDisagg[2,c("Sc2.pFF2.mean","Sc2.pFF3.mean","Sc2.pFF4.mean","Sc2.pFF5.mean","Sc2.pFF6.mean")],
              welfareByPriceFF.afterInfo.IncomeDisagg[3,c("Sc2.pFF2.mean","Sc2.pFF3.mean","Sc2.pFF4.mean","Sc2.pFF5.mean","Sc2.pFF6.mean")],
              welfareByPriceFF.afterInfo.IncomeDisagg[4,c("Sc2.pFF2.mean","Sc2.pFF3.mean","Sc2.pFF4.mean","Sc2.pFF5.mean","Sc2.pFF6.mean")],
              welfareByPriceFF.afterInfo.IncomeDisagg[5,c("Sc2.pFF2.mean","Sc2.pFF3.mean","Sc2.pFF4.mean","Sc2.pFF5.mean","Sc2.pFF6.mean")]
              )
              )
              
      # Add number of observations
        ddata$temp[ddata$PassFilter=="Yes"]<-1
        observationsByIncomegroup<-summaryBy(temp~IncomeGroupRespondent.miss, FUN=sum,  data=ddata)[,2]
        table.Welfare<-cbind(table.Welfare, c(sum(ddata$temp),  observationsByIncomegroup) )

         colnames(table.Welfare)<-c("Sc1: pff=2","Sc1: pff=3","Sc1: pff=4","Sc1: pff=5","Sc1: pff=6", "Sc2: pff=2","Sc2: pff=3","Sc2: pff=4","Sc2: pff=5","Sc2: pff=6", "No. of Observations")
         rownames(table.Welfare)<-c("Mean consumer Welfare, all incomes",
                                    "Mean consumer Welfare, below 1500€ income",
                                    "Mean consumer Welfare, below 1500-2900€ income",
                                    "Mean consumer Welfare, below 3000-4500€ income",
                                    "Mean consumer Welfare, below above 4500€ income",
                                    "No Reply"
                                    )
   
              
        
